==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ReplacementFieldFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReplacementFieldFluent<A extends ReplacementFieldFluent<A>> extends Fluent<A>{
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceSelector getSource();
  public SourceSelector buildSource();
  public A withSource(SourceSelector source);
  public Boolean hasSource();
  public ReplacementFieldFluent.SourceNested<A> withNewSource();
  public ReplacementFieldFluent.SourceNested<A> withNewSourceLike(SourceSelector item);
  public ReplacementFieldFluent.SourceNested<A> editSource();
  public ReplacementFieldFluent.SourceNested<A> editOrNewSource();
  public ReplacementFieldFluent.SourceNested<A> editOrNewSourceLike(SourceSelector item);
  public A addToTargets(Integer index,TargetSelector item);
  public A setToTargets(Integer index,TargetSelector item);
  public A addToTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items);
  public A addAllToTargets(Collection<TargetSelector> items);
  public A removeFromTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items);
  public A removeAllFromTargets(Collection<TargetSelector> items);
  public A removeMatchingFromTargets(Predicate<TargetSelectorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TargetSelector> getTargets();
  public List<TargetSelector> buildTargets();
  public TargetSelector buildTarget(Integer index);
  public TargetSelector buildFirstTarget();
  public TargetSelector buildLastTarget();
  public TargetSelector buildMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public Boolean hasMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public A withTargets(List<TargetSelector> targets);
  public A withTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... targets);
  public Boolean hasTargets();
  public ReplacementFieldFluent.TargetsNested<A> addNewTarget();
  public ReplacementFieldFluent.TargetsNested<A> addNewTargetLike(TargetSelector item);
  public ReplacementFieldFluent.TargetsNested<A> setNewTargetLike(Integer index,TargetSelector item);
  public ReplacementFieldFluent.TargetsNested<A> editTarget(Integer index);
  public ReplacementFieldFluent.TargetsNested<A> editFirstTarget();
  public ReplacementFieldFluent.TargetsNested<A> editLastTarget();
  public ReplacementFieldFluent.TargetsNested<A> editMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SourceNested<N> extends Nested<N>,SourceSelectorFluent<ReplacementFieldFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface TargetsNested<N> extends Nested<N>,TargetSelectorFluent<ReplacementFieldFluent.TargetsNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ReplacementFieldFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ReplacementFieldFluent<A extends ReplacementFieldFluent<A>> extends Fluent<A>{
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceSelector getSource();
  public SourceSelector buildSource();
  public A withSource(SourceSelector source);
  public Boolean hasSource();
  public ReplacementFieldFluent.SourceNested<A> withNewSource();
  public ReplacementFieldFluent.SourceNested<A> withNewSourceLike(SourceSelector item);
  public ReplacementFieldFluent.SourceNested<A> editSource();
  public ReplacementFieldFluent.SourceNested<A> editOrNewSource();
  public ReplacementFieldFluent.SourceNested<A> editOrNewSourceLike(SourceSelector item);
  public A addToTargets(int index,TargetSelector item);
  public A setToTargets(int index,TargetSelector item);
  public A addToTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items);
  public A addAllToTargets(Collection<TargetSelector> items);
  public A removeFromTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items);
  public A removeAllFromTargets(Collection<TargetSelector> items);
  public A removeMatchingFromTargets(Predicate<TargetSelectorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TargetSelector> getTargets();
  public List<TargetSelector> buildTargets();
  public TargetSelector buildTarget(int index);
  public TargetSelector buildFirstTarget();
  public TargetSelector buildLastTarget();
  public TargetSelector buildMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public Boolean hasMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public A withTargets(List<TargetSelector> targets);
  public A withTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... targets);
  public Boolean hasTargets();
  public ReplacementFieldFluent.TargetsNested<A> addNewTarget();
  public ReplacementFieldFluent.TargetsNested<A> addNewTargetLike(TargetSelector item);
  public ReplacementFieldFluent.TargetsNested<A> setNewTargetLike(int index,TargetSelector item);
  public ReplacementFieldFluent.TargetsNested<A> editTarget(int index);
  public ReplacementFieldFluent.TargetsNested<A> editFirstTarget();
  public ReplacementFieldFluent.TargetsNested<A> editLastTarget();
  public ReplacementFieldFluent.TargetsNested<A> editMatchingTarget(Predicate<TargetSelectorBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SourceNested<N> extends Nested<N>,SourceSelectorFluent<ReplacementFieldFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface TargetsNested<N> extends Nested<N>,TargetSelectorFluent<ReplacementFieldFluent.TargetsNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
